"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = shortcuts;

var _utils = require("./utils");

var _SelectionText = require("./SelectionText");

function shortcuts(e) {
  var api = new _SelectionText.SelectionText(e.target);

  if (e.code && e.code.toLowerCase() === 'tab') {
    (0, _utils.stopPropagation)(e);

    if (api.start === api.end) {
      api.insertText('  ').position(api.start + 2, api.end + 2);
    } else if (api.getSelectedValue().indexOf('\n') > -1 && e.shiftKey) {
      api.lineStarRemove('  ');
    } else if (api.getSelectedValue().indexOf('\n') > -1) {
      api.lineStarInstert('  ');
    } else {
      api.insertText('  ').position(api.start + 2, api.end);
    }

    api.notifyChange();
  } else if (e.code && e.code.toLowerCase() === 'enter') {
    (0, _utils.stopPropagation)(e);
    var indent = "\n".concat(api.getIndentText());
    api.insertText(indent).position(api.start + indent.length, api.start + indent.length);
    api.notifyChange();
  } else if (e.code && /^(quote|backquote|bracketleft|digit9|comma)$/.test(e.code.toLowerCase()) && api.getSelectedValue()) {
    (0, _utils.stopPropagation)(e);
    var val = api.getSelectedValue();
    var txt = '';

    switch (e.code.toLowerCase()) {
      case 'quote':
        txt = "'".concat(val, "'");

        if (e.shiftKey) {
          txt = "\"".concat(val, "\"");
        }

        break;

      case 'backquote':
        txt = "`".concat(val, "`");
        break;

      case 'bracketleft':
        txt = "[".concat(val, "]");

        if (e.shiftKey) {
          txt = "{".concat(val, "}");
        }

        break;

      case 'digit9':
        txt = "(".concat(val, ")");
        break;

      case 'comma':
        txt = "<".concat(val, ">");
        break;
    }

    api.insertText(txt);
    api.notifyChange();
  }
}

module.exports = exports.default;
//# sourceMappingURL=shortcuts.js.map